# Google Cloud Storage Audit Logs

This is the specification for the v1 Google Cloud Storage package. It only
contains the message definitions needed by Cloud Audit Logging. The v1 gRPC
service no longer runs and instead Google Cloud Storage only supports v2 API
calls. You can learn more about that in the [google/storage/v2](../v2) package.
